Roarm.Demo (RoArm v0.1.1)

Demo and testing utilities for RoArm robot control.

This module provides interactive demonstrations and testing functions to verify robot connectivity and functionality.

Summary

Functions

Demonstrate drag teach functionality.

Run a comprehensive test suite.

Interactive demo that guides the user through robot setup and testing.

Interactive teaching session.

Demo LED color cycling.

Demo LED functionality (mounted on gripper).

Demonstrate mission recording functionality.

Run a sequence of movement tests.

Demo teaching functionality - both drag teach and mission recording.

Run a basic connection test.

Demo torque lock functionality.

Advanced torque control demonstration.

Functions

drag_teach_demo()

Demonstrate drag teach functionality.

full_test_suite(port, opts \\ [])

Run a comprehensive test suite.

interactive_demo()

Interactive demo that guides the user through robot setup and testing.

interactive_teaching()

Interactive teaching session.

led_demo()

Demo LED color cycling.

led_demo_advanced()

Demo LED functionality (mounted on gripper).

mission_demo()

Demonstrate mission recording functionality.

movement_demo()

Run a sequence of movement tests.

teaching_demo()

Demo teaching functionality - both drag teach and mission recording.

test_connection(port, opts \\ [])

Run a basic connection test.

torque_demo()

Demo torque lock functionality.

torque_demo_advanced()

Advanced torque control demonstration.