Roarm.Demo (RoArm v0.1.1)
View SourceDemo and testing utilities for RoArm robot control.
This module provides interactive demonstrations and testing functions to verify robot connectivity and functionality.
Summary
Functions
Demonstrate drag teach functionality.
Run a comprehensive test suite.
Interactive demo that guides the user through robot setup and testing.
Interactive teaching session.
Demo LED color cycling.
Demo LED functionality (mounted on gripper).
Demonstrate mission recording functionality.
Run a sequence of movement tests.
Demo teaching functionality - both drag teach and mission recording.
Run a basic connection test.
Demo torque lock functionality.
Advanced torque control demonstration.
Functions
Demonstrate drag teach functionality.
Run a comprehensive test suite.
Interactive demo that guides the user through robot setup and testing.
Interactive teaching session.
Demo LED color cycling.
Demo LED functionality (mounted on gripper).
Demonstrate mission recording functionality.
Run a sequence of movement tests.
Demo teaching functionality - both drag teach and mission recording.
Run a basic connection test.
Demo torque lock functionality.
Advanced torque control demonstration.